@@ -1,6 +1,6 @@
-.reqContractDetails <- function(conn, Contract, reqId="1", conId="")
+.reqContractDetails <- function(conn, Contract, reqId="1")
 {
-    if(!inherits(conn, "twsConnection")) 
+    if(!is.twsConnection(conn))
       stop("requires twsConnection object")
 
     if(!inherits(Contract, "twsContract"))
@@ -13,7 +13,7 @@
     request <- c(.twsOutgoingMSG$REQ_CONTRACT_DATA,
                  VERSION,
                  reqId,
-                 conId,
+                 Contract$conId,
                  Contract$symbol,
                  Contract$sectype,
                  Contract$expiry,
@@ -27,11 +27,11 @@
     writeBin(as.character(request), con)            
 }
 
-`reqContractDetails` <-
-function(conn, Contract, reqId="1", conId="", verbose=FALSE,
+reqContractDetails <-
+function(conn, Contract, reqId="1", verbose=FALSE,
          eventWrapper=eWrapper(), CALLBACK=twsCALLBACK, ...) {
 
-    .reqContractDetails(conn, Contract, reqId, conId)
+    .reqContractDetails(conn, Contract, reqId)
 
     if(is.null(CALLBACK))
       invisible(return(NULL))
@@ -43,7 +43,8 @@ function(conn, Contract, reqId="1", conId="", verbose=FALSE,
       # custom contractData function called from processMsg
       twsContractDetails(version=msg[1],
                          #reqId=msg[2],
-                         contract=twsContract(symbol=msg[3],
+                         contract=twsContract(conId=msg[12+1],
+                                              symbol=msg[3],
                                               sectype=msg[4],
                                               expiry=msg[5],  
                                               primary=msg[21],
