@@ -1,5 +1,5 @@
-`twsContract` <-
-function(symbol,sectype,exch,primary,expiry,strike,
+twsContract <-
+function(conId,symbol,sectype,exch,primary,expiry,strike,
          currency,right,local,multiplier,combo_legs_desc,
          comboleg,include_expired)
 {
@@ -7,7 +7,8 @@ function(symbol,sectype,exch,primary,expiry,strike,
     return(do.call("twsContract", rep(list(NULL), 13)))
 
   structure(
-            list(symbol=symbol,
+            list(conId=conId,
+                 symbol=symbol,
                  sectype=sectype,
                  exch=exch,
                  primary=primary,
